==> react-async-wrapper-0.1.6.tgz: package/es/makeAsync.js <==
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import isPromise from 'is-promise';
import hoistStatics from 'hoist-non-react-statics';
import AsyncComponent, { DefaultErrorComponent, DefaultLoadingComponent } from './AsyncComponent';
export default (function (opts) {
  if (opts === void 0) {
    opts = {};
  }

  return function (Comp) {
    var _opts = opts,
        _opts$batch = _opts.batch,
        batch = _opts$batch === void 0 ? false : _opts$batch,
        _opts$asyncJobs = _opts.asyncJobs,
        asyncJobs = _opts$asyncJobs === void 0 ? [] : _opts$asyncJobs,
        _opts$asyncProps = _opts.asyncProps,
        asyncProps = _opts$asyncProps === void 0 ? {} : _opts$asyncProps,
        _opts$asyncPropOpts = _opts.asyncPropOpts,
        asyncPropOpts = _opts$asyncPropOpts === void 0 ? {} : _opts$asyncPropOpts,
        _opts$asyncPropsMappe = _opts.asyncPropsMapper,
        asyncPropsMapper = _opts$asyncPropsMappe === void 0 ? function (props) {
      return props;
    } : _opts$asyncPropsMappe,
        _opts$errorComponent = _opts.errorComponent,
        errorComponent = _opts$errorComponent === void 0 ? DefaultErrorComponent : _opts$errorComponent,
        _opts$loadingComponen = _opts.loadingComponent,
        loadingComponent = _opts$loadingComponen === void 0 ? DefaultLoadingComponent : _opts$loadingComponen,
        _opts$onError = _opts.onError,
        onError = _opts$onError === void 0 ? function () {
      return null;
    } : _opts$onError,
        _opts$delay = _opts.delay,
        delay = _opts$delay === void 0 ? 0 : _opts$delay,
        _opts$unwrapDefault = _opts.unwrapDefault,
        unwrapDefault = _opts$unwrapDefault === void 0 ? true : _opts$unwrapDefault;

    var C = function C(props) {
      var wrappedComponentRef = props.wrappedComponentRef,
          remainingProps = _objectWithoutProperties(props, ["wrappedComponentRef"]);

      var wrapperProps = {
        batch: batch,
        asyncJobs: asyncJobs,
        asyncProps: asyncProps,
        asyncPropOpts: asyncPropOpts,
        asyncPropsMapper: asyncPropsMapper,
        errorComponent: errorComponent,
        loadingComponent: loadingComponent,
        onError: onError,
        delay: delay,
        unwrapDefault: unwrapDefault,
        syncProps: _objectSpread({}, remainingProps, {
          ref: wrappedComponentRef
        })
      };

      if (isPromise(Comp)) {
        wrapperProps.asyncComponent = function () {
          return Comp;
        };
      } else {
        wrapperProps.component = Comp;
      }

      return React.createElement(AsyncComponent, wrapperProps);
    };

    C.displayName = "makeAsync(" + (!isPromise(Comp) ? Comp.displayName || Comp.name : 'Unknown') + ")";
    C.propTypes = {
      // eslint-disable-next-line
      wrappedComponentRef: PropTypes.func
    };
    return isPromise(Comp) ? C : hoistStatics(C, Comp);
  };
});

==> react-async-wrapper-1.0.3.tgz: package/es/makeAsync.js <==
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import isPromise from 'is-promise';
import hoistStatics from 'hoist-non-react-statics';
import AsyncComponent, { DefaultErrorComponent, DefaultLoadingComponent } from './AsyncComponent';
export default (function (opts) {
  if (opts === void 0) {
    opts = {};
  }

  return function (Comp) {
    var _opts = opts,
        _opts$batch = _opts.batch,
        batch = _opts$batch === void 0 ? false : _opts$batch,
        _opts$asyncJobs = _opts.asyncJobs,
        asyncJobs = _opts$asyncJobs === void 0 ? [] : _opts$asyncJobs,
        _opts$asyncProps = _opts.asyncProps,
        asyncProps = _opts$asyncProps === void 0 ? {} : _opts$asyncProps,
        _opts$asyncPropOpts = _opts.asyncPropOpts,
        asyncPropOpts = _opts$asyncPropOpts === void 0 ? {} : _opts$asyncPropOpts,
        _opts$asyncPropsMappe = _opts.asyncPropsMapper,
        asyncPropsMapper = _opts$asyncPropsMappe === void 0 ? function (props) {
      return props;
    } : _opts$asyncPropsMappe,
        _opts$errorComponent = _opts.errorComponent,
        errorComponent = _opts$errorComponent === void 0 ? DefaultErrorComponent : _opts$errorComponent,
        _opts$loadingComponen = _opts.loadingComponent,
        loadingComponent = _opts$loadingComponen === void 0 ? DefaultLoadingComponent : _opts$loadingComponen,
        _opts$onError = _opts.onError,
        onError = _opts$onError === void 0 ? function () {
      return null;
    } : _opts$onError,
        _opts$delay = _opts.delay,
        delay = _opts$delay === void 0 ? 0 : _opts$delay,
        _opts$unwrapDefault = _opts.unwrapDefault,
        unwrapDefault = _opts$unwrapDefault === void 0 ? true : _opts$unwrapDefault,
        _opts$reloadOnUpdate = _opts.reloadOnUpdate,
        reloadOnUpdate = _opts$reloadOnUpdate === void 0 ? false : _opts$reloadOnUpdate,
        _opts$reloadDependent = _opts.reloadDependents,
        reloadDependents = _opts$reloadDependent === void 0 ? null : _opts$reloadDependent;

    var C = function C(props) {
      var wrappedComponentRef = props.wrappedComponentRef,
          remainingProps = _objectWithoutProperties(props, ["wrappedComponentRef"]);

      var wrapperProps = {
        batch: batch,
        asyncJobs: asyncJobs,
        asyncProps: asyncProps,
        asyncPropOpts: asyncPropOpts,
        asyncPropsMapper: asyncPropsMapper,
        errorComponent: errorComponent,
        loadingComponent: loadingComponent,
        onError: onError,
        delay: delay,
        unwrapDefault: unwrapDefault,
        reloadOnUpdate: reloadOnUpdate,
        reloadDependents: reloadDependents,
        syncProps: _objectSpread({}, remainingProps, {
          ref: wrappedComponentRef
        })
      };

      if (isPromise(Comp)) {
        wrapperProps.asyncComponent = function () {
          return Comp;
        };
      } else {
        wrapperProps.component = Comp;
      }

      return React.createElement(AsyncComponent, wrapperProps);
    };

    C.displayName = "makeAsync(" + (!isPromise(Comp) ? Comp.displayName || Comp.name : 'Unknown') + ")";
    C.propTypes = {
      // eslint-disable-next-line
      wrappedComponentRef: PropTypes.func
    };
    return isPromise(Comp) ? C : hoistStatics(C, Comp);
  };
});
